#[repr(C)]pub enum ImageFlag {
New = 255,
CommitPending = 254,
Valid = 252,
Invalid = 248,
}Variants
New = 255
If the application image is running for the first time and never executed before.
CommitPending = 254
The application image is marked to execute for test boot.
Valid = 252
The application image is marked valid and committed.
Invalid = 248
The application image is marked invalid.